@@ -49,10 +49,9 @@ from django_extensions.management.utils import signalcommand
 
 def orm_item_locator(orm_obj):
     """
-    This function is called every time an object that will not be exported is required.
+    Is called every time an object that will not be exported is required.
     Where orm_obj is the referred object.
     We postpone the lookup to locate_object() which will be run on the generated script
-
     """
 
     the_class = orm_obj._meta.object_name
@@ -116,9 +115,10 @@ class Command(BaseCommand):
 
 
 def get_models(app_labels):
-    """ Gets a list of models for the given app labels, with some exceptions.
-        TODO: If a required model is referenced, it should also be included.
-        Or at least discovered with a get_or_create() call.
+    """
+    Get a list of models for the given app labels, with some exceptions.
+    TODO: If a required model is referenced, it should also be included.
+    Or at least discovered with a get_or_create() call.
     """
 
     # These models are not to be output, e.g. because they can be generated automatically
@@ -149,10 +149,11 @@ def get_models(app_labels):
 
 
 class Code(object):
-    """ A snippet of python script.
-        This keeps track of import statements and can be output to a string.
-        In the future, other features such as custom indentation might be included
-        in this class.
+    """
+    A snippet of python script.
+    This keeps track of import statements and can be output to a string.
+    In the future, other features such as custom indentation might be included
+    in this class.
     """
 
     def __init__(self, indent=-1, stdout=None, stderr=None):
@@ -167,8 +168,7 @@ class Code(object):
         self.stderr = stderr
 
     def __str__(self):
-        """ Returns a string representation of this script.
-        """
+        """ Return a string representation of this script. """
         if self.imports:
             self.stderr.write(repr(self.import_lines))
             return flatten_blocks([""] + self.import_lines + [""] + self.lines, num_indents=self.indent)
@@ -176,8 +176,7 @@ class Code(object):
             return flatten_blocks(self.lines, num_indents=self.indent)
 
     def get_import_lines(self):
-        """ Takes the stored imports and converts them to lines
-        """
+        """ Take the stored imports and converts them to lines """
         if self.imports:
             return ["from %s import %s" % (value, key) for key, value in self.imports.items()]
         else:
@@ -198,15 +197,17 @@ class ModelCode(Code):
         self.instances = []
 
     def get_imports(self):
-        """ Returns a dictionary of import statements, with the variable being
-            defined as the key.
+        """
+        Return a dictionary of import statements, with the variable being
+        defined as the key.
         """
         return {self.model.__name__: smart_text(self.model.__module__)}
     imports = property(get_imports)
 
     def get_lines(self):
-        """ Returns a list of lists or strings, representing the code body.
-            Each list is a block, each string is a statement.
+        """
+        Return a list of lists or strings, representing the code body.
+        Each list is a block, each string is a statement.
         """
         code = []
 
@@ -258,12 +259,13 @@ class InstanceCode(Code):
             self.many_to_many_waiting_list[field] = list(getattr(self.instance, field.name).all())
 
     def get_lines(self, force=False):
-        """ Returns a list of lists or strings, representing the code body.
-            Each list is a block, each string is a statement.
+        """
+        Return a list of lists or strings, representing the code body.
+        Each list is a block, each string is a statement.
 
-            force (True or False): if an attribute object cannot be included,
-            it is usually skipped to be processed later. With 'force' set, there
-            will be no waiting: a get_or_create() call is written instead.
+        force (True or False): if an attribute object cannot be included,
+        it is usually skipped to be processed later. With 'force' set, there
+        will be no waiting: a get_or_create() call is written instead.
         """
         code_lines = []
 
@@ -295,14 +297,14 @@ class InstanceCode(Code):
     lines = property(get_lines)
 
     def skip(self):
-        """ Determine whether or not this object should be skipped.
-            If this model instance is a parent of a single subclassed
-            instance, skip it. The subclassed instance will create this
-            parent instance for us.
-
-            TODO: Allow the user to force its creation?
         """
+        Determine whether or not this object should be skipped.
+        If this model instance is a parent of a single subclassed
+        instance, skip it. The subclassed instance will create this
+        parent instance for us.
 
+        TODO: Allow the user to force its creation?
+        """
         if self.skip_me is not None:
             return self.skip_me
 
@@ -364,7 +366,7 @@ class InstanceCode(Code):
         return code_lines
 
     def get_many_to_many_lines(self, force=False):
-        """ Generates lines that define many to many relations for this instance. """
+        """ Generate lines that define many to many relations for this instance. """
 
         lines = []
 
@@ -407,9 +409,10 @@ class Script(Code):
         self.options = options
 
     def _queue_models(self, models, context):
-        """ Works an an appropriate ordering for the models.
-            This isn't essential, but makes the script look nicer because
-            more instances can be defined on their first try.
+        """
+        Work an an appropriate ordering for the models.
+        This isn't essential, but makes the script look nicer because
+        more instances can be defined on their first try.
         """
         model_queue = []
         number_remaining_models = len(models)
@@ -451,8 +454,9 @@ class Script(Code):
         return model_queue
 
     def get_lines(self):
-        """ Returns a list of lists or strings, representing the code body.
-            Each list is a block, each string is a statement.
+        """
+        Return a list of lists or strings, representing the code body.
+        Each list is a block, each string is a statement.
         """
         code = [self.FILE_HEADER.strip()]
 
@@ -622,10 +626,10 @@ def import_data():
 # -------------------------------------------------------------------------------
 
 def flatten_blocks(lines, num_indents=-1):
-    """ Takes a list (block) or string (statement) and flattens it into a string
-        with indentation.
     """
-
+    Take a list (block) or string (statement) and flattens it into a string
+    with indentation.
+    """
     # The standard indent is four spaces
     INDENTATION = " " * 4
 
@@ -641,8 +645,7 @@ def flatten_blocks(lines, num_indents=-1):
 
 
 def get_attribute_value(item, field, context, force=False, skip_autofield=True):
-    """ Gets a string version of the given attribute's value, like repr() might. """
-
+    """ Get a string version of the given attribute's value, like repr() might. """
     # Find the value of the field, catching any database issues
     try:
         value = getattr(item, field.name)
@@ -708,7 +711,6 @@ def make_clean_dict(the_dict):
 
 def check_dependencies(model, model_queue, avaliable_models):
     """ Check that all the depenedencies for this model are already in the queue. """
-
     # A list of allowed links: existing fields, itself and the special case ContentType
     allowed_links = [m.model.__name__ for m in model_queue] + [model.__name__, 'ContentType']
 
